##  Grant Permissions to SAP LeanIX
After registering SAP LeanIX, the next step is to grant the necessary permissions to call APIs. Note that only the administrator in MDCA has full access and visibility to the settings and can provide the API URL.
  1. On the left pane, click API permissions.
  2. Click Add a permission.
![Granting API Permission](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ab6d77a44101490f0cd1f595ab0a9_LowRes.png)
Granting API Permission
  3. In the overlay for requesting API permissions, open the APIs my organization uses tab, then search and select Microsoft Cloud App Security API.
  4. Select Application permissions at the top and select discovery.read permission from the list below.


![Request API Permission](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274c66d07a441014a505dd6c25ffebc3_LowRes.png)
Request API Permission
  1. Click Add permissions at the bottom to assign permission to SAP LeanIX.
  2. On the API permissions page, click Grant admin consent for Default Directory to enable configured permissions.
  3. Click Yes and grant consent for the requested permissions.
  4. The permission status indicator in the API permissions page will change to approved.
